@@ -1,19 +1,42 @@
 #![doc(hidden)]
 
+#[cfg(all(test, feature = "plot"))]
+use crate::plot::prelude::SVGBackend;
 #[cfg(test)]
 use crate::*;
 
+#[test]
+fn cusp() {
+    assert_eq!(curve::cusp(HAND_CUSP, false), 1);
+    assert_eq!(curve::cusp(CRUNODE, false), 0);
+    assert_eq!(curve::cusp(OPEN_CURVE1, true), 0);
+}
+
 #[test]
 fn anti_symmetry_extension() {
     let ans = curve::anti_sym_ext(OPEN_CURVE1);
     assert_eq!(ans, OPEN_CURVE1_ANS);
 }
 
-#[cfg(all(test, feature = "plot_export"))]
+#[test]
+#[cfg(feature = "plot")]
+fn test_plot_curve() {
+    let svg = SVGBackend::new("test_curve.svg", (800, 600));
+    let curve = efd::Efd::from_curve(CRUNODE, None).generate(90);
+    plot::plot_curve(svg, "Test Curve", &[("Target", &curve)]).unwrap();
+}
+
+#[test]
+#[cfg(feature = "plot")]
+fn test_plot_history() {
+    let svg = SVGBackend::new("test_history.svg", (800, 600));
+    plot::plot_history(svg, &[1e3, 1e2, 1., 1e-2, 1e-3], 1e-3).unwrap();
+}
+
+#[cfg(all(test, feature = "plot"))]
 fn planar_synthesis(target: &[[f64; 2]], gen: u64, pop_num: usize, open: bool) {
     use crate::synthesis::*;
     use indicatif::ProgressBar;
-    use plotly::ImageFormat;
     use std::{f64::consts::TAU, fs::write};
 
     let pb = ProgressBar::new(gen);
@@ -24,20 +47,20 @@ fn planar_synthesis(target: &[[f64; 2]], gen: u64, pop_num: usize, open: bool) {
         .record(|ctx| ctx.best_f)
         .solve(Planar::new(target, 720, None, open));
     pb.finish();
-    let plot = plot::plot_history(s.report(), s.best_fitness());
-    plot.save("history.svg", ImageFormat::SVG, 800, 600, 1.);
+    let svg = SVGBackend::new("history.svg", (800, 600));
+    plot::plot_history(svg, s.report(), s.best_fitness()).unwrap();
     let ans = s.result();
     write("result.ron", ron::to_string(&ans).unwrap()).unwrap();
-    let curve = Mechanism::new(&ans).four_bar_loop(0., TAU, 360);
+    let curve = Mechanism::new(&ans).curve(0., TAU, 360);
     println!("harmonic: {}", s.func().harmonic());
     println!("seed: {}", s.seed());
+    let svg = SVGBackend::new("result.svg", (800, 600));
     let curves = [("Target", target), ("Optimized", &curve)];
-    let plot = plot::plot_curve("Synthesis Test", &curves);
-    plot.save("result.svg", ImageFormat::SVG, 800, 800, 1.);
+    plot::plot_curve(svg, "Synthesis Test", &curves).unwrap();
 }
 
-#[cfg(feature = "plot_export")]
 #[test]
+#[cfg(feature = "plot")]
 fn planar() {
     // let target = Mechanism::four_bar(FourBar {
     //     p0: (0., 0.),
@@ -69,7 +92,7 @@ fn planar() {
     //     // g: 5.,
     //     inv: false,
     // })
-    // .four_bar_loop(TAU / 6., 360);
+    // .curve(TAU / 6., 360);
     // let target = YU1;
     // let target = HAND;
     // let target = OPEN_CURVE1;
@@ -1272,7 +1295,6 @@ pub const HAND_CUSP: &[[f64; 2]] = &[
     [4.07, 6.4],
     [4.53, 6.75],
     [5.07, 6.85],
-    [5.05, 6.84],
     [5.89, 6.83],
     [6.41, 6.8],
     [6.92, 6.58],
